@@ -11,10 +11,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 """IloClient module"""
 
 import collections
+
 import netaddr
+
 from proliantutils import exception
 from proliantutils.ilo import ipmi
 from proliantutils.ilo import operations
@@ -24,6 +27,7 @@ from proliantutils.ilo.snmp import snmp_cpqdisk_sizes as snmp
 from proliantutils import log
 from proliantutils.redfish import redfish
 
+
 SUPPORTED_RIS_METHODS = [
     'activate_license',
     'clear_secure_boot_keys',
@@ -69,7 +73,7 @@ SUPPORTED_RIS_METHODS = [
     'set_vm_status',
     'update_firmware',
     'update_persistent_boot',
-    ]
+]
 
 SUPPORTED_REDFISH_METHODS = [
     'create_raid_configuration',
@@ -115,7 +119,11 @@ SUPPORTED_REDFISH_METHODS = [
     'set_iscsi_info',
     'unset_iscsi_info',
     'get_iscsi_initiator_info',
-    'set_iscsi_initiator_info'
+    'set_iscsi_initiator_info',
+    'set_http_boot_url',
+    'get_http_boot_url',
+    'add_tls_certificate',
+    'remove_tls_certificate'
 ]
 
 LOG = log.get_logger(__name__)
@@ -136,12 +144,15 @@ def cache_node(cache=True):
                     self.cls = cls
                     self._instances = collections.OrderedDict()
 
-                def _if_not_exists(self, address):
-                    return (address not in self._instances)
+                def _if_not_exists(self, ilo_info):
+                    return (ilo_info not in self._instances)
 
                 def _create_instance(self, *args, **kwargs):
                     address = args[0]
-                    self._instances[address] = self.cls(*args, **kwargs)
+                    admin = args[1]
+                    admin_pass = args[2]
+                    self._instances[(address, admin, admin_pass)] = (
+                        self.cls(*args, **kwargs))
                     # Check for max_cache_size
                     if len(self._instances) > self.MAX_CACHE_SIZE:
                         LOG.debug("Node cache hit the maximum size of %d." % (
@@ -152,20 +163,23 @@ def cache_node(cache=True):
                     if not args:
                         LOG.error("Error creating iLO object.")
                     address = args[0]
+                    admin = args[1]
+                    admin_pass = args[2]
 
-                    if self._if_not_exists(address):
+                    if self._if_not_exists((address, admin, admin_pass)):
                         LOG.debug("Creating iLO object for node %(address)s.",
                                   {'address': address})
                         self._create_instance(*args, **kwargs)
                     else:
                         LOG.debug("Using existing object for node "
                                   "%(address)s.", {'address': address})
-                    return self._instances[address]
+                    return self._instances[(address, admin, admin_pass)]
 
                 def _pop_oldest_node(self):
                     node_keys = list(self._instances)
                     node_key = next(iter(node_keys))
-                    LOG.debug("Removed oldest node %s from cache" % (node_key))
+                    LOG.debug("Removed oldest node {} from "
+                              "cache".format(node_key))
                     rnode = self._instances.pop(node_key, None)
                     if rnode:
                         del rnode
@@ -867,3 +881,17 @@ class IloClient(operations.IloOperations):
         :raises: IloError, on an error from iLO.
         """
         return self._call_method('get_available_disk_types')
+
+    def add_tls_certificate(self, cert_file_list):
+        """Adds the TLS certificate to the iLO
+
+        :raises: IloError, on an error from iLO.
+        """
+        return self._call_method('add_tls_certificate', cert_file_list)
+
+    def remove_tls_certificate(self, fp_list):
+        """Removes the TLS certificate from the iLO
+
+        :raises: IloError, on an error from iLO.
+        """
+        return self._call_method('remove_tls_certificate', fp_list)
